import debounce from 'lodash/debounce';
import registerDrawer from './_register-drawer';

export default function handleSuperHeader() {
  const superHeaderToggler = document.querySelector(
    '.global-navbar .search-icon-container'
  );

  if (!superHeaderToggler) {
    return;
  }

  const template = '/colby-college/parts/super-search.php';
  let url = `${bloginfoUrl}/wp-json/${textDomain}/get_template?template=${template}`;

  superHeaderToggler.addEventListener('click', event => {
    event.preventDefault();

    if (document.querySelector('.super-header-container')) {
      if (superHeaderToggler.classList.contains('active')) {
        closeSuperHeader(superHeaderToggler);
      } else {
        const superHeader = document.querySelector('.super-header-container');
        superHeaderToggler.classList.add('active');
        superHeader.style['margin-top'] = '0';
      }

      return;
    }

    superHeaderToggler.classList.add('active');

    fetch(url)
      .then(response => response.json())
      .then(json => {
        if (!json || !json.html) {
          return;
        }

        const newDiv = document.createElement('div');
        newDiv.setAttribute('class', 'super-header-container');
        newDiv.innerHTML = json.html;
        newDiv.style.position = 'absolute';
        newDiv.style.top = '-100%';

        document.body.insertBefore(newDiv, document.body.childNodes[(2)]);

        const insertedDiv = document.querySelector('.super-header-container');
        const child = insertedDiv.querySelector('div');

        const height = child.scrollHeight;
        newDiv.style.display = 'none';
        newDiv.style.position = 'static';

        closeSuperHeader(superHeaderToggler, newDiv, height);

        superHeaderToggler.classList.add('active');

        newDiv.style.display = 'block';

        setTimeout(
          () => {
            newDiv.style['margin-top'] = 0;
            newDiv.style.transition = 'margin .4s';
          },
          25
        );

        handleSuperHeaderTabs();
        handleSuperHeaderClose(superHeaderToggler);
        registerDrawer('.offices', '.offices-list');

        window.addEventListener(
          'resize',
          debounce(
            () => {
              if (!superHeaderToggler.classList.contains('active')) {
                closeSuperHeader();
              }
            },
            100
          )
        );
      });
  });
}

function handleSuperHeaderTabs() {
  let togglers = document.querySelectorAll(
    '.super-header-container .nav-tabs li'
  );
  let tabs = document.querySelectorAll('.super-header-container .tab-pane');

  if (!togglers || !tabs) {
    return;
  }

  togglers = [ ...togglers ];
  tabs = [ ...tabs ];

  togglers.forEach((toggler, i) => {
    toggler.addEventListener('click', event => {
      event.preventDefault();

      togglers.forEach(thisToggler => thisToggler.classList.remove('active'));
      tabs.forEach(tab => tab.classList.remove('active'));

      toggler.classList.add('active');
      tabs[i].classList.add('active');
    });
  });
}

function handleSuperHeaderClose(superHeaderToggler) {
  const closeLink = document.querySelector('.super-header-close');

  closeLink.addEventListener('click', event => {
    event.preventDefault();

    closeSuperHeader(superHeaderToggler);
  });
}

function closeSuperHeader(superHeaderToggler, superHeader, childHeight) {
  if (
    typeof childHeight === 'undefined' || typeof superHeader === 'undefined'
  ) {
    superHeader = document.querySelector('.super-header-container');
    let superChild = superHeader.querySelector('div');
    childHeight = superChild.scrollHeight;
  }

  superHeader.style['margin-top'] = `-${childHeight}px`;

  if (superHeaderToggler && superHeaderToggler.classList) {
    superHeaderToggler.classList.remove('active');
  }
}
